# v0.0.5 (16-09-2012

- Added AsyncClient!
- Added json property to Response object


# v0.0.4

- Added hooks
- Added custom pycurl options

# v0.0.3 (11-09-2011)

- Added OAuth support ( OAuth 1.0)

# v0.0.2

- Added digest auth

# v0.0.1 (31-08-2011)

- First version
- First test written 29-08-2011

Changes:

- Custom HTTP headers
- Request data/params
- Multiple file uploading
- Cookies support (dict or CookieJar)
- Redirection history
- Proxy support (http, https, socks4/5)
- Custom interface for request!
- Auto decompression of GZipped content
- Unicode URL support
- Request timers and another info
- Certificate validation
- ipv6 support